
# Type: material sample to thing association_subject




URI: [biolink:material_sample_to_thing_association_subject](https://w3id.org/biolink/vocab/material_sample_to_thing_association_subject)


## Domain and Range

[MaterialSampleToThingAssociation](MaterialSampleToThingAssociation.md) ->  <sub>REQ</sub> [MaterialSample](MaterialSample.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [MaterialSampleToThingAssociation](MaterialSampleToThingAssociation.md)
